/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.icons.web.internal.display.context;

import com.liferay.frontend.icons.web.internal.model.FrontendIconsResource;
import com.liferay.frontend.icons.web.internal.model.FrontendIconsResourcePack;
import com.liferay.frontend.icons.web.internal.repository.FrontendIconsResourcePackRepository;
import com.liferay.portal.kernel.json.JSONArray;
import com.liferay.portal.kernel.json.JSONFactoryUtil;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.json.JSONUtil;
import com.liferay.portal.kernel.portlet.url.builder.PortletURLBuilder;
import com.liferay.portal.kernel.theme.ThemeDisplay;
import com.liferay.portal.kernel.util.HashMapBuilder;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.WebKeys;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.portlet.RenderResponse;

import javax.servlet.http.HttpServletRequest;

/**
 * @author Bryce Osterhaus
 */
public class FrontendIconsSiteSettingsConfigurationDisplayContext {

	public FrontendIconsSiteSettingsConfigurationDisplayContext(
		FrontendIconsResourcePackRepository frontendIconsResourcePackRepository,
		HttpServletRequest httpServletRequest, RenderResponse renderResponse,
		String[] selectedIconPacks) {

		_frontendIconsResourcePackRepository =
			frontendIconsResourcePackRepository;
		_renderResponse = renderResponse;
		_selectedIconPacks = selectedIconPacks;

		_themeDisplay = (ThemeDisplay)httpServletRequest.getAttribute(
			WebKeys.THEME_DISPLAY);
	}

	public Map<String, Object> getProps() {
		return HashMapBuilder.<String, Object>put(
			"allIconResourcePacks",
			() -> {
				JSONObject jsonObject = JSONFactoryUtil.createJSONObject();

				List<FrontendIconsResourcePack> frontendIconsResourcePacks =
					_frontendIconsResourcePackRepository.
						getFrontendIconsResourcePacks(
							_themeDisplay.getCompanyId());

				for (FrontendIconsResourcePack frontendIconsResourcePack :
						frontendIconsResourcePacks) {

					JSONArray jsonArray = JSONFactoryUtil.createJSONArray();

					List<FrontendIconsResource> frontendIconsResources =
						new ArrayList<>(
							frontendIconsResourcePack.
								getFrontendIconsResources());

					for (FrontendIconsResource frontendIconsResource :
							frontendIconsResources) {

						jsonArray.put(
							JSONUtil.put(
								"name", frontendIconsResource.getName()));
					}

					jsonObject.put(
						frontendIconsResourcePack.getName(),
						JSONUtil.put("icons", jsonArray));
				}

				return jsonObject;
			}
		).put(
			"saveSiteIconPacksURL",
			PortletURLBuilder.createActionURL(
				_renderResponse
			).setActionName(
				"/site_settings/save_site_frontend_icons_packs"
			).buildString()
		).put(
			"siteIconResourcePacks",
			() -> {
				JSONArray jsonArray = JSONFactoryUtil.createJSONArray();

				for (String selectedIconPack : _selectedIconPacks) {
					jsonArray.put(StringUtil.toUpperCase(selectedIconPack));
				}

				return jsonArray;
			}
		).build();
	}

	private final FrontendIconsResourcePackRepository
		_frontendIconsResourcePackRepository;
	private final RenderResponse _renderResponse;
	private final String[] _selectedIconPacks;
	private final ThemeDisplay _themeDisplay;

}