/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.icons.web.internal.model;

import com.liferay.portal.kernel.util.StringUtil;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Bryce Osterhaus
 */
public class FrontendIconsResourcePack {

	public FrontendIconsResourcePack(boolean editable, String name) {
		_editable = editable;
		_name = StringUtil.toUpperCase(name);
	}

	public FrontendIconsResourcePack(String name) {
		this(true, name);
	}

	public void addFrontendIconsResource(
		FrontendIconsResource frontendIconsResource) {

		_frontendIconsResources.put(
			frontendIconsResource.getName(), frontendIconsResource);
	}

	public void addFrontendIconsResources(
		List<FrontendIconsResource> frontendIconsResources) {

		frontendIconsResources.forEach(this::addFrontendIconsResource);
	}

	public void deleteFrontendIconsResource(String name) {
		_frontendIconsResources.remove(name);
	}

	public FrontendIconsResource getFrontendIconsResource(String name) {
		return _frontendIconsResources.get(name);
	}

	public Collection<FrontendIconsResource> getFrontendIconsResources() {
		List<FrontendIconsResource> frontendIconsResources = new ArrayList<>(
			_frontendIconsResources.values());

		Collections.sort(
			frontendIconsResources,
			Comparator.comparing(FrontendIconsResource::getName));

		return frontendIconsResources;
	}

	public String getName() {
		return _name;
	}

	public boolean isEditable() {
		return _editable;
	}

	private final boolean _editable;
	private final Map<String, FrontendIconsResource> _frontendIconsResources =
		new HashMap<>();
	private final String _name;

}