/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.icons.web.internal.servlet.taglib;

import com.liferay.petra.string.StringBundler;
import com.liferay.portal.kernel.frontend.icons.FrontendIconsUtil;
import com.liferay.portal.kernel.servlet.taglib.BaseDynamicInclude;
import com.liferay.portal.kernel.servlet.taglib.DynamicInclude;
import com.liferay.portal.kernel.theme.ThemeDisplay;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.PropsUtil;
import com.liferay.portal.kernel.util.WebKeys;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.osgi.service.component.annotations.Component;

/**
 * @author Bryce Osterhaus
 */
@Component(immediate = true, service = DynamicInclude.class)
public class FrontendIconsSpritemapTopHeadDynamicInclude
	extends BaseDynamicInclude {

	@Override
	public void include(
			HttpServletRequest httpServletRequest,
			HttpServletResponse httpServletResponse, String key)
		throws IOException {

		PrintWriter printWriter = httpServletResponse.getWriter();

		StringBundler sb = new StringBundler(5);

		sb.append("<script data-senna-track=\"temporary\">");
		sb.append("var Liferay = window.Liferay || {};");
		sb.append("Liferay.Icons = Liferay.Icons || {};");
		sb.append(
			StringBundler.concat(
				"Liferay.Icons.basePath = '", FrontendIconsUtil.getBasePath(),
				"';"));

		ThemeDisplay themeDisplay =
			(ThemeDisplay)httpServletRequest.getAttribute(
				WebKeys.THEME_DISPLAY);

		sb.append(
			StringBundler.concat(
				"Liferay.Icons.spritemap = '",
				FrontendIconsUtil.getSpritemap(themeDisplay), "';"));

		if (GetterUtil.getBoolean(PropsUtil.get("feature.flag.LPS-145112"))) {
			sb.append(
				StringBundler.concat(
					"Liferay.Icons.systemSpritemap = '",
					FrontendIconsUtil.getSystemSpritemap(), "';"));
		}
		else {
			sb.append(
				StringBundler.concat(
					"Liferay.Icons.systemSpritemap = '",
					FrontendIconsUtil.getSpritemap(themeDisplay), "';"));
		}

		sb.append("</script>");

		printWriter.println(sb);
	}

	@Override
	public void register(DynamicIncludeRegistry dynamicIncludeRegistry) {
		dynamicIncludeRegistry.register("/html/common/themes/top_head.jsp#pre");
	}

}